==> apache-iceberg-1.9.2.tar.gz: apache-iceberg-1.9.2/data/src/test/java/org/apache/iceberg/parquet/TestGenericMergingMetrics.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.parquet;

import java.io.File;
import java.io.IOException;
import java.util.List;
import org.apache.iceberg.Files;
import org.apache.iceberg.TestMergingMetrics;
import org.apache.iceberg.data.GenericAppenderFactory;
import org.apache.iceberg.data.Record;
import org.apache.iceberg.io.FileAppender;

public class TestGenericMergingMetrics extends TestMergingMetrics<Record> {

  @Override
  protected FileAppender<Record> writeAndGetAppender(List<Record> records) throws IOException {
    FileAppender<Record> appender =
        new GenericAppenderFactory(SCHEMA)
            .newAppender(
                Files.localOutput(File.createTempFile("junit", null, tempDir)), fileFormat);
    try (FileAppender<Record> fileAppender = appender) {
      records.forEach(fileAppender::add);
    }
    return appender;
  }
}

==> apache-iceberg-1.10.1.tar.gz: apache-iceberg-1.10.1/data/src/test/java/org/apache/iceberg/parquet/TestGenericMergingMetrics.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.iceberg.parquet;

import java.io.File;
import java.io.IOException;
import java.util.List;
import org.apache.iceberg.Files;
import org.apache.iceberg.TestMergingMetrics;
import org.apache.iceberg.data.GenericAppenderFactory;
import org.apache.iceberg.data.Record;
import org.apache.iceberg.io.FileAppender;

public class TestGenericMergingMetrics extends TestMergingMetrics<Record> {

  @Override
  protected FileAppender<Record> writeAndGetAppender(List<Record> records) throws IOException {
    FileAppender<Record> appender =
        new GenericAppenderFactory(SCHEMA)
            .newAppender(
                Files.localOutput(new File(tempDir, "junit" + System.nanoTime())), fileFormat);
    try (FileAppender<Record> fileAppender = appender) {
      records.forEach(fileAppender::add);
    }
    return appender;
  }
}
